@@ -17,9 +17,10 @@
  *************************************************************************************/
 
 #include <QApplication>
+#include <QCommandLineParser>
 #include <KAboutData>
+#include <KLocalizedString>
 #include "kalgebra.h"
-#include <klocalizedstring.h>
 
 int main(int argc, char *argv[])
 {
@@ -30,6 +31,11 @@ int main(int argc, char *argv[])
     about.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
     KAboutData::setApplicationData(about);
 
+    QCommandLineParser parser;
+    about.setupCommandLine(&parser);
+    parser.process(app);
+    about.processCommandLine(&parser);
+
     KLocalizedString::setApplicationDomain("kalgebra");
 
     KAlgebra widget;
